@@ -7,9 +7,9 @@ use PadWalker ();
 require 5.005003;
 
 @ISA = qw(Exporter DynaLoader);
-@EXPORT_OK = qw( caller_cv called_with );
+@EXPORT_OK = qw( caller_cv called_with called_as_method );
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 bootstrap Devel::Caller $VERSION;
 
@@ -31,6 +31,14 @@ sub caller_cv {
     return _context_cv($cx);
 }
 
+
+sub called_as_method {
+    my $level = shift || 0;
+    my $cx = PadWalker::_upcontext($level + 1);
+    return unless $cx;
+    _called_as_method($cx);
+}
+
 1;
 __END__
 
@@ -67,6 +75,11 @@ variables will be returned instead
 
 constants are returned as C<undef> in both cases
 
+=item called_as_method($level)
+
+C<called_as_method> returns true if the subroutine at $level was
+called as a method.
+
 =head1 BUGS
 
 All of these routines are susceptible to the same limitations as
